@@ -34,7 +34,6 @@
 
 #include "sasl-handler.h"
 #include "tls-handler.h"
-#include "conference-auth-observer.h"
 #include "version.h"
 
 #include <KTp/telepathy-handler-application.h>
@@ -50,7 +49,6 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(ki18n("David Edmundson"), ki18n("Developer"), "kde@davidedmundson.co.uk");
     aboutData.addAuthor(ki18n("Daniele E. Domenichelli"), ki18n("Developer"), "daniele.domenichelli@gmail.com");
     aboutData.setProductName("telepathy/auth-handler");
-    aboutData.setProgramIconName(QLatin1String("telepathy-kde"));
 
     KCmdLineArgs::init(argc, argv, &aboutData);
     KTp::TelepathyHandlerApplication app;
@@ -70,22 +68,24 @@ int main(int argc, char *argv[])
 
     int handlers = 1;
 
-    Tp::SharedPtr<SaslHandler> saslHandler = Tp::SharedPtr<SaslHandler>(new SaslHandler);
+    Tp::ChannelClassSpecList saslFilter;
+    QVariantMap saslOtherProperties;
+    saslOtherProperties.insert(
+            TP_QT_IFACE_CHANNEL_TYPE_SERVER_AUTHENTICATION + QLatin1String(".AuthenticationMethod"),
+            TP_QT_IFACE_CHANNEL_INTERFACE_SASL_AUTHENTICATION);
+    saslFilter.append(Tp::ChannelClassSpec(TP_QT_IFACE_CHANNEL_TYPE_SERVER_AUTHENTICATION,
+                Tp::HandleTypeNone, false, saslOtherProperties));
+    Tp::SharedPtr<SaslHandler> saslHandler = Tp::SharedPtr<SaslHandler>(new SaslHandler(saslFilter));
     if (!clientRegistrar->registerClient(
                 Tp::AbstractClientPtr(saslHandler), QLatin1String("KTp.SASLHandler"))) {
         handlers -= 1;
     }
 
-    Tp::ChannelClassSpecList confAuthFilter =  Tp::ChannelClassSpecList() << Tp::ChannelClassSpec::textChatroom();
-    Tp::SharedPtr<ConferenceAuthObserver> confAuthObserver = Tp::SharedPtr<ConferenceAuthObserver>(new ConferenceAuthObserver(confAuthFilter));
-    if (!clientRegistrar->registerClient(
-                Tp::AbstractClientPtr(confAuthObserver), QLatin1String("KTp.ConfAuthObserver"))) {
-	    kWarning() << "Could not register the room auth observer!";
-    }
-
-
 #if 0
-    Tp::SharedPtr<TlsHandler> tlsHandler = Tp::SharedPtr<TlsHandler>(new TlsHandler);
+    Tp::ChannelClassSpecList tlsFilter;
+    tlsFilter.append(Tp::ChannelClassSpec(TP_QT_IFACE_CHANNEL_TYPE_SERVER_TLS_CONNECTION,
+                Tp::HandleTypeNone, false));
+    Tp::SharedPtr<TlsHandler> tlsHandler = Tp::SharedPtr<TlsHandler>(new TlsHandler(tlsFilter));
     if (!clientRegistrar->registerClient(
                 Tp::AbstractClientPtr(tlsHandler), QLatin1String("KTp.TLSHandler"))) {
         handlers -= 1;
